@@ -5,11 +5,11 @@ from typing import Any
 
 from multiauth.config import PY_MULTIAUTH_LOGGER as logger
 from multiauth.handlers import auth_handler, reauth_handler
+from multiauth.manager import User, UserManager
 from multiauth.providers.aws import aws_signature
 from multiauth.types.abst import MultiAuthBase
 from multiauth.types.http import HTTPMethod
 from multiauth.types.main import Token
-from multiauth.user_manager import User, UserManager
 
 
 class MultiAuth(MultiAuthBase):
@@ -84,6 +84,8 @@ class MultiAuth(MultiAuthBase):
         if auth_response and isinstance(auth_response, dict):
             self._headers[username] = auth_response['headers']
             logger.info('Authentication Successful')
+        else:
+            self._headers[username] = {}
 
         return self._headers[username], username
 
